/*
 * Copyright (C) 1998 Kunihiro Ishiguro
 *
 * This file is part of GNU Zebra.
 *
 * GNU Zebra is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * GNU Zebra is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Zebra; see the file COPYING.  If not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.  
 */

#ifndef _ZEBRA_PIM_FSM_H
#define _ZEBRA_PIM_FSM_H

/* Macro for PIM read add */
#define PIM_READ_ON(T,F,A,V) \
      if (!(T)) \
        (T) = thread_add_read (master, (F), A, (V))

/* Macro for PIM read off. */
#define PIM_READ_OFF(X) \
      if (X) \
	{ \
	  thread_cancel (X); \
	  (X) = NULL; \
	}

/* Macro for PIM write add */
#define PIM_WRITE_ON(T,F,A,V) \
      if (!(T)) \
        (T) = thread_add_write (master, (F), A, (V))

/* Macro for PIM write turn off. */
#define PIM_WRITE_OFF(X) \
      if (X) \
	{ \
	  thread_cancel (X); \
	  (X) = NULL; \
	}

/* Macro for timer turn on. */
#define PIM_TIMER_ON(T,F,A,V) \
      if (!(T)) \
        (T) = thread_add_timer (master, (F), A, (V))

/* Macro for timer turn off. */
#define PIM_TIMER_OFF(X) \
      if (X) \
	{ \
	  thread_cancel (X); \
	  (X) = NULL; \
	}

#define PIM_EVENT_ADD(P,E) \
      thread_add_event (master, PIM_event, (P), (E))

/* Prototypes. */
int pim_event (struct thread *);
void pim_timer_set (struct pim_neighbor *);
void pim_stop (struct pim_neighbor *pim_neighbor);


#endif /* _ZEBRA_PIM_FSM_H */
