/*
 *
 * Copyright (C) 2000  Robert Olsson, Jens Ls 
 * Swedish University of Agricultural Sciences
 *
 * This file is part of GNU Zebra.
 *
 * GNU Zebra is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * GNU Zebra is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Zebra; see the file COPYING.  If not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.  
 */

#include <zebra.h>
#include "vector.h"
#include "vty.h"
#include "command.h"
#include "getopt.h"
#include "thread.h"
#include "stream.h"
#include "network.h"
#include "prefix.h"
#include "version.h"
#include "memory.h"
#include "if.h"
#include "sockunion.h"
#include "log.h"
#include "pim.h"
#include "pimd.h"
#include "pim_fsm.h"
#include <netinet/ip_mroute.h>
#include "tables.h"
#include "pim_route.h"
#include <netinet/igmp.h>
#include "if_ioctl.h"
#include "pim_packet.h"
#include "igmp_def.h"
#include "if_idx_nexthop.h"

#include "zbug.h"
char b1[16], b2[16], b3[16], b4[16];  /* For inet_2a */


/* Some code to get things going... */

u_int32_t rp;

u_int32_t
select_rp(u_int32_t g)
{
  return rp;
}

DEFUN (ip_pim_rp,
       ip_pim_rp_cmd,
       "ip pim rp A.B.C.D",
       "pim rendezvous point\n"
       "pim rendezvous point\n")
{
  struct in_addr a;
  int ret;

  ret = inet_aton (argv[0], &a);
  if (!ret) {
      vty_out (vty, "Malformed address %s", VTY_NEWLINE);
      return CMD_WARNING;
    }
  rp = a.s_addr;
 return CMD_SUCCESS;
}

DEFUN (no_ip_pim_rp,
       no_ip_pim_rp_cmd,
       "no ip pim rp A.B.C.D",
       "Unset pim rendezvous point\n"
       "Unset pim rendezvous point\n")
{
  struct in_addr a;
  int ret;

  ret = inet_aton (argv[0], &a);
  if (!ret) {
      vty_out (vty, "Malformed address %s", VTY_NEWLINE);
      return CMD_WARNING;
    }
  rp = 0;
 return CMD_SUCCESS;
}

void
pim_rp_init()
{
 install_element (CONFIG_NODE, &ip_pim_rp_cmd); 
}

